@@ -19,12 +19,13 @@ from core_oaipmh_provider_app.components.oai_provider_metadata_format.models imp
 from core_oaipmh_provider_app.components.oai_provider_set.models import OaiProviderSet
 from core_oaipmh_provider_app.components.oai_settings.models import OaiSettings
 from core_oaipmh_provider_app.components.oai_xsl_template.models import OaiXslTemplate
-from django_mongoengine.forms import DocumentForm
 
 logger = logging.getLogger(__name__)
 
 
-class EditIdentityForm(DocumentForm):
+class EditIdentityForm(forms.ModelForm):
+    """Edit Identity Form"""
+
     repository_name = forms.CharField(
         label="Name",
         widget=forms.TextInput(
@@ -33,7 +34,7 @@ class EditIdentityForm(DocumentForm):
     )
 
     enable_harvesting = forms.BooleanField(
-        label="Enable Harvesting ?",
+        label="Enable Harvesting?",
         required=False,
         initial=False,
         widget=forms.CheckboxInput(),
@@ -45,12 +46,14 @@ class EditIdentityForm(DocumentForm):
         widget=forms.TextInput(attrs={"class": "form-control"}),
     )
 
-    class Meta(object):
-        document = OaiSettings
+    class Meta:
+        """Meta"""
+
+        model = OaiSettings
         fields = ["repository_name", "repository_identifier", "enable_harvesting"]
 
 
-class MetadataFormatForm(DocumentForm):
+class MetadataFormatForm(forms.ModelForm):
     """
     A metadata format form.
     """
@@ -68,12 +71,14 @@ class MetadataFormatForm(DocumentForm):
         widget=forms.URLInput(attrs={"class": "form-control"}),
     )
 
-    class Meta(object):
-        document = OaiProviderMetadataFormat
+    class Meta:
+        """Meta"""
+
+        model = OaiProviderMetadataFormat
         fields = ["metadata_prefix", "schema"]
 
 
-class EditMetadataFormatForm(DocumentForm):
+class EditMetadataFormatForm(forms.ModelForm):
     """
     A metadata format edit form.
     """
@@ -85,12 +90,14 @@ class EditMetadataFormatForm(DocumentForm):
         ),
     )
 
-    class Meta(object):
-        document = OaiProviderMetadataFormat
+    class Meta:
+        """Meta"""
+
+        model = OaiProviderMetadataFormat
         fields = ["metadata_prefix"]
 
 
-class TemplateMetadataFormatForm(DocumentForm):
+class TemplateMetadataFormatForm(forms.ModelForm):
     """
     A template metadata format form.
     """
@@ -106,21 +113,23 @@ class TemplateMetadataFormatForm(DocumentForm):
         label="Template", widget=forms.Select(attrs={"class": "form-control"})
     )
 
-    class Meta(object):
-        document = OaiProviderMetadataFormat
+    class Meta:
+        """Meta"""
+
+        model = OaiProviderMetadataFormat
         fields = ["metadata_prefix", "template"]
 
     def __init__(self, *args, **kwargs):
         self.request = kwargs.pop("request")
-        super(TemplateMetadataFormatForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields["template"].choices = _get_templates_versions(request=self.request)
 
     def clean_template(self):
         data = self.cleaned_data["template"]
-        return template_api.get(data, request=self.request)
+        return template_api.get_by_id(data, request=self.request)
 
 
-class SetForm(DocumentForm):
+class SetForm(forms.ModelForm):
     """
     A Set edit form.
     """
@@ -151,19 +160,26 @@ class SetForm(DocumentForm):
         ),
     )
 
-    class Meta(object):
-        document = OaiProviderSet
-        fields = ["set_spec", "set_name", "templates_manager", "description"]
+    class Meta:
+        """Meta"""
+
+        model = OaiProviderSet
+        fields = [
+            "set_spec",
+            "set_name",
+            "templates_manager",
+            "description",
+        ]
 
     def __init__(self, *args, **kwargs):
         request = kwargs.pop("request")
-        super(SetForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields["templates_manager"].choices = _get_templates_manager(
             request=request
         )
 
 
-class MappingXSLTForm(DocumentForm):
+class MappingXSLTForm(forms.ModelForm):
     """
     A MappingXSLTForm form.
     """
@@ -181,14 +197,16 @@ class MappingXSLTForm(DocumentForm):
         label="XSLT", widget=forms.Select(attrs={"class": "form-control"})
     )
 
-    class Meta(object):
-        document = OaiXslTemplate
+    class Meta:
+        """Meta"""
+
+        model = OaiXslTemplate
         fields = ["oai_metadata_format", "template", "xslt"]
 
     def __init__(self, *args, **kwargs):
         self.request = kwargs.pop("request")
         edit_mode = kwargs.pop("edit_mode", None)
-        super(MappingXSLTForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields["template"].choices = _get_templates_versions(request=self.request)
         self.fields["xslt"].choices = _get_xsl_transformation()
         if edit_mode:
@@ -200,7 +218,7 @@ class MappingXSLTForm(DocumentForm):
 
     def clean_template(self):
         data = self.cleaned_data["template"]
-        return template_api.get(data, request=self.request)
+        return template_api.get_by_id(data, request=self.request)
 
 
 def _get_templates_versions(request):
@@ -217,11 +235,11 @@ def _get_templates_versions(request):
         )
         for elt in list_:
             for version in elt.versions:
-                template = template_api.get(version, request=request)
+                template = template_api.get_by_id(version, request=request)
                 version_name = template.display_name
                 templates.append((version, version_name))
-    except exceptions.DoesNotExist as e:
-        logger.warning("_get_templates_versions threw an exception: {0}".format(str(e)))
+    except exceptions.DoesNotExist as exception:
+        logger.warning("_get_templates_versions threw an exception: %s", str(exception))
 
     return templates
 
