@@ -3,13 +3,12 @@
 
 from unittest.case import TestCase
 
-from bson.objectid import ObjectId
-from mock.mock import Mock, patch
+from unittest.mock import Mock, patch
 
-import core_oaipmh_provider_app.components.oai_xsl_template.api as oai_xsl_template_api
 from core_main_app.commons import exceptions
 from core_main_app.components.template.models import Template
 from core_main_app.components.xsl_transformation.models import XslTransformation
+import core_oaipmh_provider_app.components.oai_xsl_template.api as oai_xsl_template_api
 from core_oaipmh_provider_app.components.oai_provider_metadata_format.models import (
     OaiProviderMetadataFormat,
 )
@@ -17,11 +16,16 @@ from core_oaipmh_provider_app.components.oai_xsl_template.models import OaiXslTe
 
 
 class TestOaiXslTemplateUpsert(TestCase):
+    """Test Oai Xsl Template Upsert"""
+
     def setUp(self):
+        """setUp"""
         self.mock_oai_xsl_template = _create_oai_xsl_template()
 
     @patch.object(OaiXslTemplate, "save")
     def test_oai_xsl_template_upsert_returns_object(self, mock_save):
+        """test_oai_xsl_template_upsert_returns_object"""
+
         # Arrange
         mock_save.return_value = self.mock_oai_xsl_template
 
@@ -33,6 +37,8 @@ class TestOaiXslTemplateUpsert(TestCase):
 
     @patch.object(OaiXslTemplate, "save")
     def test_oai_xsl_template_upsert_raises_error_if_save_failed(self, mock_save):
+        """test_oai_xsl_template_upsert_raises_error_if_save_failed"""
+
         # Arrange
         mock_save.side_effect = Exception()
 
@@ -42,8 +48,12 @@ class TestOaiXslTemplateUpsert(TestCase):
 
 
 class TestOaiXslTemplateDelete(TestCase):
+    """Test Oai Xsl Template Delete"""
+
     @patch.object(OaiXslTemplate, "delete")
     def test_delete_oai_xsl_template_raises_exception_if_error(self, mock_delete):
+        """test_delete_oai_xsl_template_raises_exception_if_error"""
+
         # Arrange
         oai_xsl_template = _create_oai_xsl_template()
         mock_delete.side_effect = Exception()
@@ -54,11 +64,15 @@ class TestOaiXslTemplateDelete(TestCase):
 
 
 class TestOaiXslTemplateGetById(TestCase):
+    """Test Oai Xsl Template Get By Id"""
+
     @patch.object(OaiXslTemplate, "get_by_id")
     def test_get_by_id_returns_object(self, mock_get_by_id):
+        """test_get_by_id_returns_object"""
+
         # Arrange
         mock_oai_xsl_template = _create_oai_xsl_template()
-        mock_oai_xsl_template.id = ObjectId()
+        mock_oai_xsl_template.id = 1
 
         mock_get_by_id.return_value = mock_oai_xsl_template
 
@@ -70,8 +84,10 @@ class TestOaiXslTemplateGetById(TestCase):
 
     @patch.object(OaiXslTemplate, "get_by_id")
     def test_get_by_id_raises_exception_if_object_does_not_exist(self, mock_get_by_id):
+        """test_get_by_id_raises_exception_if_object_does_not_exist"""
+
         # Arrange
-        mock_absent_id = ObjectId()
+        mock_absent_id = 1
 
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error.")
 
@@ -81,8 +97,10 @@ class TestOaiXslTemplateGetById(TestCase):
 
     @patch.object(OaiXslTemplate, "get_by_id")
     def test_get_by_id_raises_exception_if_internal_error(self, mock_get_by_id):
+        """test_get_by_id_raises_exception_if_internal_error"""
+
         # Arrange
-        mock_absent_id = ObjectId()
+        mock_absent_id = 1
 
         mock_get_by_id.side_effect = exceptions.ModelError("Error.")
 
@@ -92,12 +110,16 @@ class TestOaiXslTemplateGetById(TestCase):
 
 
 class TestOaiXslTemplateGetByTemplateIdAndMetadataFormatId(TestCase):
+    """Test Oai Xsl Template Get By Template Id And Metadata Format Id"""
+
     @patch.object(OaiXslTemplate, "get_by_template_id_and_metadata_format_id")
     def test_get_by_id_returns_object(self, mock_get_by_id_and_metadata_format_id):
+        """test_get_by_id_returns_object"""
+
         # Arrange
         mock_oai_xsl_template = _create_oai_xsl_template()
-        template_id = ObjectId()
-        metadata_format_id = ObjectId()
+        template_id = 1
+        metadata_format_id = 1
 
         mock_get_by_id_and_metadata_format_id.return_value = mock_oai_xsl_template
 
@@ -113,8 +135,10 @@ class TestOaiXslTemplateGetByTemplateIdAndMetadataFormatId(TestCase):
     def test_get_by_id_raises_exception_if_object_does_not_exist(
         self, mock_get_by_template_id_and_metadata_format_id
     ):
+        """test_get_by_id_raises_exception_if_object_does_not_exist"""
+
         # Arrange
-        mock_absent_id = ObjectId()
+        mock_absent_id = 1
 
         mock_get_by_template_id_and_metadata_format_id.side_effect = (
             exceptions.DoesNotExist("Error.")
@@ -130,8 +154,10 @@ class TestOaiXslTemplateGetByTemplateIdAndMetadataFormatId(TestCase):
     def test_get_by_id_raises_exception_if_internal_error(
         self, mock_get_by_template_id_and_metadata_format_id
     ):
+        """test_get_by_id_raises_exception_if_internal_error"""
+
         # Arrange
-        mock_absent_id = ObjectId()
+        mock_absent_id = 1
 
         mock_get_by_template_id_and_metadata_format_id.side_effect = (
             exceptions.ModelError("Error.")
@@ -145,18 +171,25 @@ class TestOaiXslTemplateGetByTemplateIdAndMetadataFormatId(TestCase):
 
 
 class TestOaiXslTemplateGetAllByTemplate(TestCase):
+    """Test Oai Xsl Template Get All By Template"""
+
     @patch.object(OaiXslTemplate, "get_all_by_templates")
     def test_get_all_by_template_contains_only_oai_xsl_template(self, mock_get_all):
+        """test_get_all_by_template_contains_only_oai_xsl_template"""
         _generic_get_all_test(
             self, mock_get_all, oai_xsl_template_api.get_all_by_templates(Template())
         )
 
 
 class TestOaiXslTemplateGetAllByMetadataFormat(TestCase):
+    """Test Oai Xsl Template Get All By Metadata Format"""
+
     @patch.object(OaiXslTemplate, "get_all_by_metadata_format")
     def test_get_all_by_metadata_format_contains_only_oai_xsl_template(
         self, mock_get_all
     ):
+        """test_get_all_by_metadata_format_contains_only_oai_xsl_template"""
+
         _generic_get_all_test(
             self,
             mock_get_all,
@@ -167,8 +200,12 @@ class TestOaiXslTemplateGetAllByMetadataFormat(TestCase):
 
 
 class TestOaiXslTemplateGetTemplatesIdsByMetadataFormat(TestCase):
+    """Test Oai Xsl Template Get Templates Ids By Metadata Format"""
+
     @patch.object(OaiXslTemplate, "get_all_by_metadata_format")
     def test_get_template_ids_by_metadata_format(self, mock_get):
+        """test_get_template_ids_by_metadata_format"""
+
         # Arrange
         mock_oai_xsl_template1 = _create_mock_oai_xsl_template()
 
@@ -180,12 +217,16 @@ class TestOaiXslTemplateGetTemplatesIdsByMetadataFormat(TestCase):
         )
 
         # Assert
-        self.assertEquals(mock_oai_xsl_template1.template.id, result[0])
+        self.assertEqual(mock_oai_xsl_template1.template.id, result[0])
 
 
 class TestOaiXslTemplateGetMetadataFormatsByTemplates(TestCase):
+    """Test Oai Xsl Template Get Metadata Formats By Templates"""
+
     @patch.object(OaiXslTemplate, "get_all_by_templates")
     def test_get_metadata_formats_by_templates(self, mock_get):
+        """test_get_metadata_formats_by_templates"""
+
         # Arrange
         mock_oai_xsl_template1 = _create_mock_oai_xsl_template()
 
@@ -195,7 +236,7 @@ class TestOaiXslTemplateGetMetadataFormatsByTemplates(TestCase):
         result = oai_xsl_template_api.get_metadata_formats_by_templates([Template()])
 
         # Assert
-        self.assertEquals(mock_oai_xsl_template1.oai_metadata_format, result[0])
+        self.assertEqual(mock_oai_xsl_template1.oai_metadata_format, result[0])
 
 
 def _generic_get_all_test(self, mock_get_all, act_function):
@@ -246,7 +287,7 @@ def _set_oai_xsl_template_fields(oai_xsl_template):
 
     """
     oai_xsl_template.template = Template()
-    oai_xsl_template.template.id = ObjectId()
+    oai_xsl_template.template.id = 1
     oai_xsl_template.xslt = XslTransformation()
     oai_xsl_template.oai_metadata_format = OaiProviderMetadataFormat()
 
